==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adreiça deu vòste sit', # MODIF
	'form_pet_aucune_signature' => 'Nada signatura non correspond pas a aqueth còde...', # MODIF
	'form_pet_confirmation' => 'Volhatz confirmar la vòsta signatura:',
	'form_pet_deja_signe' => 'Qu’avetz ja signat aqueth tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Ara que receberatz un e-mail de confirmacion. Tà validar la vòsta signatura, que cau vesitar l’adreiça web mençonada per aqueste corrièr.', # MODIF
	'form_pet_mail_confirmation' => 'Adishatz,

qu’avetz demandat de signar la peticion:
@titre@.

Qu’avetz hornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Tà validar la vòsta signatura, que sufís de’vs connectar a 
 l’adreiça ça devath (senon que’s regetarà
la vòsta demanda): 
    @url@


Mercés entà la vòsta participacion
', # MODIF
	'form_pet_nom_site2' => 'Nom deu vòste sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, las signaturas que son temporàriament arrestadas.',
	'form_pet_signature_validee' => 'La vòsta signatura qu’ei validada. Mercés!',
	'form_pet_site_deja_enregistre' => 'Ja aqueth sit qu’ei registrat',
	'form_pet_url_invalide' => 'L’URL qui avetz indicada n’ei pas valida.',
	'form_pet_votre_email' => 'La vòsta adreiça e-mail',
	'form_pet_votre_nom' => 'Lo vòste nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tienetz un sit, qu’ac podetz marcar ça devath',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Responsa a l’article'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_gsc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_gsc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Nada peticion',
	'bouton_radio_petition_activee' => 'Peticion activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreiça deu vòste sit', # MODIF
	'form_pet_aucune_signature' => 'Nada signatura non correspond pas a aqueth còde...', # MODIF
	'form_pet_confirmation' => 'Volhatz confirmar la vòsta signatura:',
	'form_pet_deja_signe' => 'Qu’avetz ja signat aqueth tèxt.',
	'form_pet_envoi_mail_confirmation' => 'Ara que receberatz un e-mail de confirmacion. Tà validar la vòsta signatura, que cau vesitar l’adreiça web mençonada per aqueste corrièr.', # MODIF
	'form_pet_mail_confirmation' => 'Adishatz,

qu’avetz demandat de signar la peticion:
@titre@.

Qu’avetz hornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Tà validar la vòsta signatura, que sufís de’vs connectar a 
 l’adreiça ça devath (senon que’s regetarà
la vòsta demanda): 
    @url@


Mercés entà la vòsta participacion
', # MODIF
	'form_pet_nom_site2' => 'Nom deu vòste sit web', # MODIF
	'form_pet_probleme_technique' => 'Problèma tecnic, las signaturas que son temporàriament arrestadas.',
	'form_pet_signature_validee' => 'La vòsta signatura qu’ei validada. Mercés!',
	'form_pet_site_deja_enregistre' => 'Ja aqueth sit qu’ei registrat',
	'form_pet_url_invalide' => 'L’URL qui avetz indicada n’ei pas valida.',
	'form_pet_votre_email' => 'La vòsta adreiça e-mail',
	'form_pet_votre_nom' => 'Lo vòste nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tienetz un sit, qu’ac podetz marcar ça devath',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Responsa a l’article'
);

?>
